/***************************************************************************/
/* shatest.c								   */
/*									   */
/* Main program to drive sha.c, performing SHA-1 over a file		   */
/* and printing the resulting digest in two ways -- as long words and	   */
/* as a byte array.							   */
/*									   */
/* This is for verification of the implementation for machines of 	   */
/* different endianness. 						   */
/*									   */
/*  Carl M. Ellison, 3 Feb 1998, from code by Peter Gutmann in 1992.	   */
/*									   */
/*  Note: the hash of "abc" (3 bytes) should be				   */
/*  A9993E36 4706816A BA3E2571 7850C26C 9CD0D89D			   */
/*									   */
/***************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include "sha.h"

/* Size of buffer for SHA speed test data */

#define TEST_BLOCK_SIZE     ( 8192 )

/* Number of bytes of test data to process */

#define TEST_BYTES          10000000L
#define TEST_BLOCKS         ( TEST_BYTES / TEST_BLOCK_SIZE )

void main( int argc, char **argv )
{
  SHA_INFO shaInfo;
  BYTE data[ TEST_BLOCK_SIZE ];
  long i;
  FILE *ifile ;
  BYTE hash[ SHA_DIGESTSIZE ] ;

  /* Read a file, if there is a parameter, or stdin */
  if (argc < 2) ifile = stdin ;
  else if ((ifile = fopen( argv[1], "rb" )) == NULL) ifile = stdin ;

  if (argc > 2) {
    shaInit( &shaInfo );
    shaUpdate( &shaInfo, (BYTE *) "abc", 3 );
    shaFinal( &shaInfo, hash );
  } else {
    shaInit( &shaInfo );
    while ((i=fread(data, 1, TEST_BLOCK_SIZE, ifile)) > 0)
      shaUpdate( &shaInfo, data, i );
    shaFinal( &shaInfo, hash );
  } /* else */

  for (i=0; i<SHA_DIGESTSIZE; i++)
    printf( " %02X", hash[i] ) ;
  printf( "\n" ) ;

  for (i=0; i<5; i++)
    printf( " %08X", shaInfo.digest[i] ) ;
  printf( "\n" ) ;
} /* main */